CHANGES
=======

0.2.2 (2019-10-15)
------------------

- In tokenize() method, `emoji_threshold` parameter is available
- Bugfix

0.2.1 (2019-10-12)
------------------

- Works well with also a text including emoticon and www (Laughing expression)
- Always treat emoji to delimiter regardless MeCab's POS

0.1.1 (2019-10-05)
------------------

- First release
